@@ -331,7 +331,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2(javaEnv,dirs):
+def build2(javaEnv,dirs,buildApi=="True",buildWorker="True"):
 
 
     # ensure maven installs all build tools
@@ -339,30 +339,33 @@ def build2(javaEnv,dirs):
     local('mvn clean install -DskipTests')
 
 
-    local('mkdir -p deploy/api/config')
-    local('mkdir -p deploy/api/lib')
- 
-    local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
-    local('cp config/logback.xml deploy/api/config/')
-    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
+    if buildApi in TRUTH_VALUES:
+	    local('mkdir -p deploy/api/config')
+	    local('mkdir -p deploy/api/lib')
+	 
+	    local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
+	    local('cp config/logback.xml deploy/api/config/')
+	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
-    local('cp -r api/target/lib/ deploy/api/')
+	    local('cp -r api/target/lib/ deploy/api/')
 
-    local('cp api/target/*SNAPSHOT.jar deploy/api/')
+	    local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
 
-    local('mkdir -p deploy/worker/config')
-    local('mkdir -p deploy/worker/lib')
+	if buildWorker in TRUTH_VALUES:
+	    local('mkdir -p deploy/worker/config')
+	    local('mkdir -p deploy/worker/lib')
 
-    local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
-    local('cp config/logback.xml deploy/worker/config/')
-    local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
-    local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
-    local('cp config/initiate_shutdown.sql deploy/worker/config/')
+	    local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
+	    local('cp config/logback.xml deploy/worker/config/')
+	    local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
+	    local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
+	    local('cp config/initiate_shutdown.sql deploy/worker/config/')
+	    local('cp config/finish-deploy.sh deploy/worker/config/')
 
-    local('cp -r worker/target/lib/ deploy/worker/')
+	    local('cp -r worker/target/lib/ deploy/worker/')
 
-    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
+	    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
 
 
 
